@@ -1,10 +1,12 @@
 #ifndef NSTD_GL_H_INCLUDED
 #define NSTD_GL_H_INCLUDED
 #include "gl/buffer.h"
+#include "gl/command.h"
 #include "gl/def.h"
 #include "gl/device.h"
 #include "gl/instance.h"
-#include "gl/pipeline.h"
+#include "gl/render.h"
+#include "gl/shader.h"
 #include "gl/state.h"
 #include "gl/surface.h"
 #include "gl/texture.h"
