@@ -11,9 +11,9 @@ typedef NSTDAny NSTDGLCommandEncoder;
 
 /// Creates a gpu command encoder.
 /// Parameters:
-///     `const NSTDGLDevice device` - The device to create commands for.
+///     `const NSTDGLDevice *const device` - The device to create commands for.
 /// Returns: `NSTDGLCommandEncoder command_encoder` - The new gpu command encoder.
-NSTDAPI NSTDGLCommandEncoder nstd_gl_command_encoder_new(const NSTDGLDevice device);
+NSTDAPI NSTDGLCommandEncoder nstd_gl_command_encoder_new(const NSTDGLDevice *const device);
 
 /// Frees a command encoder and returns a command buffer.
 /// Parameters:
@@ -22,5 +22,13 @@ NSTDAPI NSTDGLCommandEncoder nstd_gl_command_encoder_new(const NSTDGLDevice devi
 NSTDAPI NSTDGLCommandBuffer nstd_gl_command_encoder_finish(
     NSTDGLCommandEncoder *const command_encoder);
 
+/// Frees a command encoder and submits the command buffer to the device immediately.
+/// Parameters:
+///     `NSTDGLCommandEncoder *const command_encoder` - The gpu command encoder.
+///     `const NSTDGLDevice *const device` - The device to submit the command buffer to.
+NSTDAPI void nstd_gl_command_encoder_finish_submit(
+    NSTDGLCommandEncoder *const command_encoder,
+    const NSTDGLDevice *const device);
+
 NSTDCPPEND
 #endif
