@@ -1,3 +1,6 @@
+pub mod device_id;
+pub mod window_id;
+use self::{device_id::NSTDDeviceID, window_id::NSTDWindowID};
 use crate::{
     core::def::NSTDBool,
     gui::def::{NSTDWindowPosition, NSTDWindowSize},
@@ -20,18 +23,11 @@ use winit::platform::windows::EventLoopExtWindows;
 use winit::{
     event::*,
     event_loop::{ControlFlow, EventLoop, EventLoopWindowTarget},
-    window::WindowId,
 };
 
 /// An event loop handle.
 pub type NSTDEventLoop = *mut EventLoop<()>;
 
-/// Represents a window ID.
-pub type NSTDWindowID = *mut WindowId;
-
-/// Represents a device ID.
-pub type NSTDDeviceID = *const DeviceId;
-
 /// Represents an event loop's control flow.
 #[repr(C)]
 #[allow(non_camel_case_types)]
