@@ -1,8 +1,10 @@
 pub mod buffer;
+pub mod command;
 pub mod def;
 pub mod device;
 pub mod instance;
-pub mod pipeline;
+pub mod render;
+pub mod shader;
 pub mod state;
 pub mod surface;
 pub mod texture;
