@@ -1,5 +1,6 @@
 pub mod config;
-use crate::{gl::instance::NSTDGLInstance, gui::NSTDWindow};
+pub mod texture;
+use crate::{gl::instance::NSTDGLInstance, gui::window::NSTDWindow};
 use wgpu::Surface;
 
 /// Represents a graphical surface.
